import { Api } from "./Api";
import Model from "./Model";
import Hash from "./Hash";
import StoreCache from "./StoreCache";
import StoreFetch from "./StoreFetch";
import { Callback } from "./ModelResponse";
export interface Options {
    url?: string;
    queryParams?: string | Hash<any>;
    callback?: Callback;
}
export interface FetchOptions extends Options {
    ignoreCache?: boolean;
}
export interface FetchListOptions extends FetchOptions {
    completeItems?: boolean;
}
export interface ActOptions extends Options {
    data?: Hash<any>;
    method?: string;
}
export default class Store<T extends Model> extends Api {
    model: typeof Model;
    cache: StoreCache<T>;
    protected _fetch: StoreFetch<T>;
    constructor(model: typeof Model, properties?: Hash<any>);
    readonly path: string;
    protected readonly fetch: StoreFetch<T>;
    index(options?: FetchListOptions): Promise<T[]>;
    get(key: any, options?: FetchOptions): Promise<T>;
    create(values: Hash<any>, options?: Options): Promise<T>;
    update(key: any, values: Hash<any>, options?: Options): Promise<T>;
    destroy(key: T | any, options?: Options): Promise<void>;
    by(model: typeof Model, key: any, options?: FetchListOptions): Promise<T[]>;
    foreign(model: typeof Model, key: any, options?: FetchListOptions): Promise<Model[]>;
    act(options?: ActOptions): Promise<any>;
}
